% This m-file produces a truncated square wave that is modulated and sent
%   to the computer speakers.

clear
Tend = 30;             % time length
FS = 8192;          % sampling frequency, common with sound files
time = 0:1/FS:Tend;
npoints = length(time)-1;
Fc = 3000;          
wc = 2*Fc*pi;   %carrier frequency

% create the square wave x(t) with offset so that it is positive and has
% magnitude < 1 (to avoid clipping when transmitted using the sound command

T = 4;                           % period of square wave
npoints_T_half = round(T*FS/2);    % number of points for 1/2 cycle
x_int = ones(1,npoints_T_half);
t = 0;
ncycles = 1;
x = [];

while t < 12,
    x = [x 0*x_int 0.9*x_int ];
    t = t+T;
end
x = [x zeros(1,(length(time)-length(x)))];

figure(1)

plot(time,x);
axis([0 30 0 2]);
xlabel('Time (sec)')
ylabel('x(t)')


S = x.*cos(time*wc);

figure(2)
plot(time,x)
title('x(t)');
xlabel('Time(sec)')
figure(3)
subplot(111)
plot(time,S,'k')
title('(a)'); %Generated Sound data
xlabel('Time (sec)')
ylabel('Signal Sent to Speakers')
sound(S,FS)

% downsample x to have the same length and approximate sampling time as 
%   the recorded signal y(t).  This is needed for the system identification procedure.

ny = 5000;  % number of points in the data file for y, with sampling period of 0.006
inc = round(npoints/ny);
x = x(1:inc:end);
if length(x)>5000,
    x = x(1:5000);
elseif length(x)<5000,
    x = [x zeros(1,5000-length(x))];
end
time = 0:.006:length(x);

time = 0:0.006:Tend;
time = time(1:5000);
npoints = length(time)-1;

% create the square wave x(t) with offset so that it is positive and has
% magnitude < 1 (to avoid clipping when transmitted using the sound command

npoints_T_half = round(T/.006/2);    % number of points for 1/2 cycle
x_int = ones(1,npoints_T_half);
t = 0;
ncycles = 1;
x = [];

while t < 12,
    x = [x 0*x_int 0.9*x_int ];
    t = t+T;
end
x = [x zeros(1,(length(time)-length(x)))];