% This m-file produces a chirp signal that is modulated and sent to the speakers
% The result is a signal that oscillates in intensity at an increasing rate

clear
T = 30;             % time length
FS = 8192;          % sampling frequency
time = 0:1/FS:T;
npoints = length(time)-1;
Fc = 3000;    % carrier frequency    
wc = 2*Fc*pi;   

% chirp signal m(t) where the frequency increases exponentially
x_startf = 0.05;   %start frequency
x_endf = 1.5;      %end frequency
dxf = log10(x_endf/x_startf)/npoints;  % log spacing
logxf = log10(x_startf):dxf:log10(x_endf);
xf = 10.^logxf;
x = cos(time.*xf*2*pi);
env = 0.3*x + 0.6;

S = env.*cos(time*wc);

figure(2)
plot(time,env)
title('Envelope');
xlabel('Time(sec)')
figure(3)
subplot(211)
plot(time,S,'k')
title('(a)'); %Generated Sound data
xlabel('Time (sec)')
ylabel('Signal Sent to Speakers')
sound(S,FS)

% downsample x to have the same length and approximate sampling time as 
%   the recorded signal y(t).  This is needed for the system identification procedure.

time = 0:.006:T;

time = time(1:5000);
npoints = length(time)-1;

% chirp signal m(t) where the frequency increases exponentially
x_startf = 0.05;   %start frequency
x_endf = 1.5;      %end frequency
dxf = log10(x_endf/x_startf)/npoints;  % log spacing
logxf = log10(x_startf):dxf:log10(x_endf);
xf = 10.^logxf;
x = cos(time.*xf*2*pi);
env = 0.3*x + 0.6;

